﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Input;
using System.Threading.Tasks;
using ArcGIS.Core.CIM;
using ArcGIS.Core.Data;
using ArcGIS.Core.Geometry;
using ArcGIS.Desktop.Catalog;
using ArcGIS.Desktop.Core;
using ArcGIS.Desktop.Editing;
using ArcGIS.Desktop.Extensions;
using ArcGIS.Desktop.Framework;
using ArcGIS.Desktop.Framework.Contracts;
using ArcGIS.Desktop.Framework.Dialogs;
using ArcGIS.Desktop.Framework.Threading.Tasks;
using ArcGIS.Desktop.Mapping;

namespace CameraProperties
{
    internal class Module1 : Module
    {


        private static Module1 _this = null;

        /// <summary>
        /// Retrieve the singleton instance to this module here
        /// </summary>
        public static Module1 Current
        {
            get
            {
                return _this ?? (_this = (Module1)FrameworkApplication.FindModule("CameraProperties_Module"));
            }
        }

        #region Overrides
        /// <summary>
        /// Called by Framework when ArcGIS Pro is closing
        /// </summary>
        /// <returns>False to prevent Pro from closing, otherwise True</returns>
        protected override bool CanUnload()
        {
            //TODO - add your business logic
            //return false to ~cancel~ Application close
            return true;
        }

        #endregion Overrides

        #region Business Logic

        public RollValCombobox RollValueCombobox { get; set; }

        public void CreateNewKeyFrame()
        {
            QueuedTask.Run(() =>
            {
                var currentmapview = MapView.Active;
                var currentcamera = currentmapview.Camera;
                var newCamera = currentcamera;

                var viewAnimation = currentmapview.Animation;
                var currentAnimationTime = viewAnimation.CurrentTime;
                var mapAnimation = currentmapview.Map.Animation;
                var cameraTrack = mapAnimation.Tracks.OfType<CameraTrack>().First();

                // Check the entered roll value and if valid, create a keyframe using it.
                var rollValue = RollValueCombobox.Text;
                if (Double.TryParse(rollValue, out double dblRollValue))
                {
                    newCamera.Roll = dblRollValue;
                    cameraTrack.CreateKeyframe(newCamera, currentAnimationTime, AnimationTransition.Linear);
                }
                else
                {
                    ArcGIS.Desktop.Framework.Dialogs.MessageBox.Show("Roll value can't be used, please re-enter a valid number.");
                    RollValueCombobox.Text = "";
                }
            });
        }

        #endregion




    }
}


